# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61gent_server.proto\x12\x13octopus_agent_proto\x1a\x0c\x63ommon.proto\"4\n\x0fSendTaskRequest\x12\x13\n\x0binput_files\x18\x01 \x03(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\",\n\rOnAgentAction\x12\r\n\x05input\x18\x01 \x01(\t\x12\x0c\n\x04tool\x18\x02 \x01(\t\"8\n\x10OnAgentActionEnd\x12\x0e\n\x06output\x18\x01 \x01(\t\x12\x14\n\x0coutput_files\x18\x02 \x03(\t\"\x1e\n\x0c\x46inalRespond\x12\x0e\n\x06\x61nswer\x18\x01 \x01(\t\"\x92\x02\n\x0bTaskRespond\x12\x13\n\x0btoken_usage\x18\x01 \x01(\x05\x12\x11\n\titeration\x18\x02 \x01(\x05\x12\x12\n\nmodel_name\x18\x03 \x01(\t\x12=\n\x0fon_agent_action\x18\x05 \x01(\x0b\x32\".octopus_agent_proto.OnAgentActionH\x00\x12\x44\n\x13on_agent_action_end\x18\x06 \x01(\x0b\x32%.octopus_agent_proto.OnAgentActionEndH\x00\x12:\n\rfinal_respond\x18\x07 \x01(\x0b\x32!.octopus_agent_proto.FinalRespondH\x00\x42\x06\n\x04\x62ody\"1\n\x10\x41\x64\x64KernelRequest\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\".\n\x11\x41\x64\x64KernelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xf0\x02\n\x0b\x41gentServer\x12Q\n\x06upload\x12\x1f.octopus_common_proto.FileChunk\x1a\".octopus_common_proto.FileUploaded\"\x00(\x01\x12V\n\x08\x64ownload\x12%.octopus_common_proto.DownloadRequest\x1a\x1f.octopus_common_proto.FileChunk\"\x00\x30\x01\x12W\n\tsend_task\x12$.octopus_agent_proto.SendTaskRequest\x1a .octopus_agent_proto.TaskRespond\"\x00\x30\x01\x12]\n\nadd_kernel\x12%.octopus_agent_proto.AddKernelRequest\x1a&.octopus_agent_proto.AddKernelResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_server_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SENDTASKREQUEST']._serialized_start=57
  _globals['_SENDTASKREQUEST']._serialized_end=109
  _globals['_ONAGENTACTION']._serialized_start=111
  _globals['_ONAGENTACTION']._serialized_end=155
  _globals['_ONAGENTACTIONEND']._serialized_start=157
  _globals['_ONAGENTACTIONEND']._serialized_end=213
  _globals['_FINALRESPOND']._serialized_start=215
  _globals['_FINALRESPOND']._serialized_end=245
  _globals['_TASKRESPOND']._serialized_start=248
  _globals['_TASKRESPOND']._serialized_end=522
  _globals['_ADDKERNELREQUEST']._serialized_start=524
  _globals['_ADDKERNELREQUEST']._serialized_end=573
  _globals['_ADDKERNELRESPONSE']._serialized_start=575
  _globals['_ADDKERNELRESPONSE']._serialized_end=621
  _globals['_AGENTSERVER']._serialized_start=624
  _globals['_AGENTSERVER']._serialized_end=992
# @@protoc_insertion_point(module_scope)
